import QtQuick 1.1
import com.nokia.meego 1.0

import QtMobility.location 1.2
import QtMobility.sensors 1.2
import QtMobility.systeminfo 1.2

import "js/storage.js" as Storage
import "js/util.js"    as Util

Page
{
   id: commonPage
   tools: commonTools

   property string  _title          : "GPS Locator"

   property string  _time           : "RESOLVING..."

   property string  _provider       : "RESOLVING..."
   property string  _latitude       : "RESOLVING..."
   property string  _longitude      : "RESOLVING..."
   property string  _altitude       : "RESOLVING..."
   property string  _accuracy       : "RESOLVING..."

   property string  _bearing        : "RESOLVING..."
   property string  _speed          : "RESOLVING..."

   property string  _battery        : "RESOLVING..."
   property string  _battery_status : "RESOLVING..."



   property Coordinate currentCoord

   Component.onCompleted: Storage.initialize();

   DeviceInfo { id: devinfo; }

   Connections
   {
      target: Application
      onActiveChanged:
      {
         if (Application.active)
            positionSource.start();
         else
            positionSource.stop();
      }
   }

   PositionSource
   {
      id                : positionSource
      updateInterval    : Util.convertMinToMs(Storage.getSetting("LOCATOR","UPDATE_INTERVAL"));
      active            : true

      onPositionChanged : updateGPS();
   }

   Compass
   {
      id: compass
      // Create a variable to hold azimuth
      property double azimuth: 0
      // Turn on the sensor
      active: true
      onReadingChanged:
      {
          // Called when a new compass reading is available
          compass.azimuth = reading.azimuth;
      }
   }

   Coordinate
   {
      id        : cur_db_coord
      latitude  : 37.781038
      longitude : 55.660739
   }

   function getPositionSourceMethod(method)
   {
       //console.log("GPS Provider2: " + PositionSource.SatellitePositioningMethod);

      if (method == PositionSource.SatellitePositioningMethod)
         return "GPS";
      else if (method == PositionSource.NoPositioningMethod)
         return "NotAvailable"
      else if (method == PositionSource.NonSatellitePositioningMethod)
         return "СellularNetwork"
      else if (method == PositionSource.AllPositioningMethods)
         return "Multiple"
      return "Error";
   }

   function getGpsFormat(coord)
   {
       //0 - decimal
       //1 - degrees:minutes
       //2 - degrees:minutes:seconds
       var vGpsFormat = Storage.getSetting('PROGRAMM','COORDINATE_FORMAT');
       if (!Util.isNumber(vGpsFormat))
           return coord;

       //console.log("GPS Format-: " + vGpsFormat);
       if (vGpsFormat == 1)
           return Util.convertDecimalToDM(coord);
       else if (vGpsFormat == 2)
           return Util.convertDecimalToDMS(coord);
       else
           return coord;
   }

   function updateGPS()
   {
       var vUseGPS = Storage.getSetting('LOCATOR','PROVIDER');

       setGPSInfo();
   }

   function setGPSInfo()
   {
       currentCoord = positionSource.position.coordinate;
       //console.log(getGpsFormat(currentCoord.latitude.toFixed(6)));

       if (Util.isNumber(currentCoord.latitude))
       {
           var vCurrSpeed = Util.getSpeedKm(positionSource.position.speed);
           vCurrSpeed = vCurrSpeed < 0 ? 0 : vCurrSpeed;

           var vProvider = getPositionSourceMethod(positionSource.positioningMethod);
           //console.log("GPS Provider: " + vProvider);
           _latitude  = getGpsFormat(currentCoord.latitude.toFixed(6));
           _longitude = getGpsFormat(currentCoord.longitude.toFixed(6));
           _altitude  = getGpsFormat(currentCoord.altitude.toFixed(6));
           _speed     = vCurrSpeed;
           _time      = positionSource.position.timestamp;
           _accuracy  = positionSource.position.horizontalAccuracy.toFixed(2);
           _bearing   = compass.azimuth.toString();
           _battery   = devinfo.batteryLevel
           _battery_status = devinfo.currentPowerState == 3 ? 1 : 0;

           console.log(_battery_status);

           var vParams = '';
           //console.log(vParams.length);

           vParams += "&accuracy=" + _accuracy;

           if (Storage.getSetting('CALLBACK','SEND_ALTITUDE') === "Y")
              vParams += "&altitude=" + _altitude;

           if (vProvider !== "Error")
               _provider = vProvider;

           if (Storage.getSetting('CALLBACK','SEND_PROVIDER') === "Y")
           {
               if (vProvider !== "Error")
                  vParams += "&provider=" + vProvider;
           }

           if (Storage.getSetting('CALLBACK','SEND_BEARING') === "Y")
              vParams += "&bearing=" + _bearing;

           if (Storage.getSetting('CALLBACK','SEND_SPEED') === "Y")
              vParams += "&speed=" + _speed;

           if (Storage.getSetting('CALLBACK','SEND_TIME') === "Y")
              vParams += "&time=" + _time;

           if (Storage.getSetting('CALLBACK','SEND_BATT_STATUS') === "Y")
              vParams += "&battlevel=" + _battery + "&charging=" + _battery_status;

           var vSecret = Storage.getSetting('CALLBACK','SECRET');
           if (vSecret.length > 0)
               vParams += "&secret=" + vSecret;

           if (Storage.getSetting('CALLBACK','SEND_DEVID') === "Y")
              vParams += "&deviceid=" + devinfo.imei;

           if (Storage.getSetting('CALLBACK','SEND_SUBSCRID') === "Y")
              vParams += "&subscriberid=" + devinfo.imsi;








          ////console.log(vParams.length);
          ////console.log(vParams);
          ////console.log(vCurrSpeed);
          Storage.setCurrentLocation(_latitude,_longitude,vParams);

          //speedInfo.text = vCurrSpeed + "Км/ч";
       }
       else
       {
           //console.log("Not valid Coord");
       }

   }

   Image
   {
      id: pageHeader
      anchors
      {
         top:   commonPage.top
         left:  commonPage.left
         right: commonPage.right
      }

      height: parent.width < parent.height ? 72 : 46
      width:  parent.width

      source: "image://theme/meegotouch-view-header-fixed" + (theme.inverted ? "-inverted" : "")
      z: 1

      Label
      {
         id: header
         anchors
         {
            verticalCenter: parent.verticalCenter
            left:           parent.left
            leftMargin:     16
         }
         platformStyle: LabelStyle
         {
            fontFamily:    "Nokia Pure Text Light"
            fontPixelSize: 32
         }
         text: commonPage._title
      }
   }

   Flickable
   {
      id: pageFlickableContent
      anchors
      {
         top:     pageHeader.bottom
         bottom:  commonPage.bottom
         left:    commonPage.left
         right:   commonPage.right
         margins: 16
      }
      contentHeight:      pageContent.height
      contentWidth:       pageContent.width
      flickableDirection: Flickable.VerticalFlick

      Column
      {
         id:      pageContent
         width:   commonPage.width - pageFlickableContent.anchors.margins * 2
         spacing: 16



         Text
         {
            id: txtTime
            text: "Time: " + _time
            font.pixelSize: 24
         }

         Text
         {
            id: txtProvider
            text: "Provider: " + _provider
            font.pixelSize: 24
         }


         Text
         {
            id: txtLatitude
            text: "Latitude: " + _latitude
            font.pixelSize: 24
         }
         Text
         {
            id: txtLongitude
            text: "Longitude: " + _longitude
            font.pixelSize: 24
         }
         Text
         {
            id: txtAltitude
            text: "Altitude: " + _altitude
            font.pixelSize: 24
         }
         Text
         {
            id: txtAccuracy
            text: "Accuracy: " + _accuracy
            font.pixelSize: 24
         }


         Text
         {
            id: txtBearing
            text: "Bearing: " + _bearing
            anchors.top: txtAccuracy.bottom
            anchors.topMargin: 16
            font.pixelSize: 24
         }

         Text
         {
            id: txtSpeed
            text: "Speed: " + _speed
            font.pixelSize: 24
         }

         Text
         {
            id: txtBattery
            text: "Battery: " + _battery
            anchors.top: txtSpeed.bottom
            anchors.topMargin: 16
            font.pixelSize: 24
         }
      }
   }


   ScrollDecorator
   {
      flickableItem: pageFlickableContent
   }
}
