// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import com.nokia.meego 1.1

import "js/storage.js" as Storage

Page
{

id : pageSettings


tools: ToolBarLayout
   {
      ToolIcon
      {
         visible: pageStack.depth > 1
         platformIconId: "toolbar-back"
         onClicked:
         {
            pageStack.pop();
         }
      }
   }

   Flickable
   {
      id: container
      anchors {
          top: pageSettings.top
          bottom: pageSettings.bottom
          left: pageSettings.left
          right: pageSettings.right
          margins: 16
      }
      contentHeight: list.height
      contentWidth: list.width
      flickableDirection: Flickable.VerticalFlick
      Column
      {
         id:  list
         spacing: 16
         height: childrenRect.height
         width: pageSettings.width - container.anchors.margins * 2

      Text
      {
            id: txtProgramSettings;
            text: "Programm Settings";
            font.family: "Nokia Pure Text Light"
            font.pixelSize: 24
            font.capitalization: Font.AllUppercase
            anchors.top: parent;
            anchors.topMargin: 10;
            anchors.margins: 10;
      }

      Item
      {
         id : itmGpsFormat
         anchors.top: txtProgramSettings.bottom
         anchors.topMargin: 10
         anchors.margins: 10;
         height: 40;
         width: parent.width
         Text
         {
             id: txtGpsFormat
             text:"Coordinate Format "
             font.family: "Nokia Pure Text Light"
             font.pixelSize: 24
             font.weight: bold
         }
         MouseArea
         {
            anchors.fill: parent
            onClicked:
            {
                gpsFormatDialog.open();
            }
         }
      }

      Text
      {
         id: txtLocatorSettings;
         text: "Locator Settings";
         font.family: "Nokia Pure Text Light"
         font.pixelSize: 24
         font.capitalization: Font.AllUppercase
         anchors.top: parent;
         anchors.topMargin: 10;
         anchors.margins: 10;
      }

      Item
      {
         id : inpUpdateInterval
         anchors.top: txtLocatorSettings.bottom
         anchors.topMargin: 10
         anchors.margins: 10;
         height: 40;
         width: 200;
         Text
         {
             id: lblUpdateInterval
             lineHeight: 40
             text:"Update Interval(min): "
             font.family: "Nokia Pure Text Light"
             font.pixelSize: 24
             font.weight: bold
             height: 40;
             verticalAlignment: inpUpdateInterval.Center

         }
         TextField
         {
             id:txtInpUpdInterval
             anchors.left: lblUpdateInterval.right

             width:parent.width - 10;
             text: Storage.getSetting('LOCATOR','UPDATE_INTERVAL');
             Keys.onReturnPressed:
             {
                platformCloseSoftwareInputPanel()

                var vUpdateInterval = txtInpUpdInterval.text;
                //console.log("UPDATE_INTERVAL: " + vUpdateInterval);
                Storage.setSetting('LOCATOR', 'UPDATE_INTERVAL',vUpdateInterval);
             }
         }
      }

      Item
      {
         id : inpGPSTimeOut
         anchors.top: inpUpdateInterval.bottom
         anchors.topMargin: 20
         anchors.margins: 10;
         height: 40;
         width: 200;
         Text
         {
             id: lblGPSTimeOut
             lineHeight: 40
             text:"GPS TimeOut: "
             font.family: "Nokia Pure Text Light"
             font.pixelSize: 24
             font.weight: bold
             height: 40;
             verticalAlignment: inpGPSTimeOut.Center

         }
         TextField
         {
             id:txtInpGPSTimeOut
             anchors.left: lblGPSTimeOut.right

             width:parent.width - 10;
             text: Storage.getSetting('LOCATOR','GPS_TIMEOUT');
             Keys.onReturnPressed:
             {
                platformCloseSoftwareInputPanel()

                var vGPSTimeOut = txtInpGPSTimeOut.text;
                //console.log("GPS_TIMEOUT: " + vGPSTimeOut);
                Storage.setSetting('LOCATOR', 'GPS_TIMEOUT',vGPSTimeOut);
             }
         }
      }

     /* Item
      {
         id : boxLocatorProvider
         anchors.top: inpGPSTimeOut.bottom
         anchors.topMargin: 20
         anchors.margins: 10;
         height: 40;
         CheckBox
         {
            text : "Use GPS or the cellular networks";
            checked: (Storage.getSetting('LOCATOR','PROVIDER') === "Y") ? true : false;
            onClicked:
            {
               var vSendProvider = Storage.getSetting('LOCATOR','PROVIDER') === "Y" ? 'N' : 'Y';
               //console.log("Use GPS or the cellular networks:" + vSendProvider);
               Storage.setSetting('LOCATOR', 'PROVIDER',vSendProvider);
            }
         }
      }

      Item
      {
         id : boxContiniousMode
         anchors.top: boxLocatorProvider.bottom
         anchors.topMargin: 10
         anchors.margins: 10;
         height: 40;
         CheckBox
         {
            text : "Keep the locator running";
            checked: (Storage.getSetting('LOCATOR','CONTINIOUS_MODE') === "Y") ? true : false;
            onClicked:
            {
               var vSendProvider = Storage.getSetting('LOCATOR','CONTINIOUS_MODE') === "Y" ? 'N' : 'Y';
               //console.log("Use GPS or the cellular networks:" + vSendProvider);
               Storage.setSetting('LOCATOR', 'CONTINIOUS_MODE',vSendProvider);
            }
         }
      }
*/

      Text
      {
         id: txtCallBackSettings;
         text: "CallBack Settings";
         font.family: "Nokia Pure Text Light"
         font.pixelSize: 24
         font.capitalization: Font.AllUppercase
         anchors.top: boxContiniousMode.bottom;
         anchors.topMargin: 20;
         anchors.margins: 10;

      }

      Item
      {
         id : inpUrl
         anchors.top: txtCallBackSettings.bottom
         anchors.topMargin: 10
         anchors.margins: 10;
         height: 40;
         width: parent.width
         Text
         {
             id: lblURL
             lineHeight: 40
             text:"URL: "
             font.family: "Nokia Pure Text Light"
             font.pixelSize: 24
             font.weight: bold
             height: 40;
             verticalAlignment: inpUrl.Center

         }
         TextField
         {
             id:txtInputURL
             anchors.left: lblURL.right

             width:parent.width - lblURL.width - 10;
             text: Storage.getSetting('CALLBACK','URL');
             Keys.onReturnPressed:
             {
                platformCloseSoftwareInputPanel()

                var vURL = txtInputURL.text;
                //console.log("URL: " + vURL);
                Storage.setSetting('CALLBACK', 'URL',vURL);
             }
         }
      }

      Item
      {
         id : inpSecret
         anchors.top: inpUrl.bottom
         anchors.topMargin: 20
         anchors.margins: 10;
         height: 40;
         width: parent.width
         Text
         {
             id: lblSecret
             lineHeight: 40
             text:"Secret:"
             font.family: "Nokia Pure Text Light"
             font.pixelSize: 24
             font.weight: Font.bold
             height: 40;
             verticalAlignment: inpSecret.Center

         }
         TextField
         {
             id:txtInputSecret
             anchors.left: lblSecret.right

             width:parent.width - lblSecret.width - 10;
             text: Storage.getSetting('CALLBACK','SECRET');
             Keys.onReturnPressed:
             {
                platformCloseSoftwareInputPanel()

                var vSecret = txtInputSecret.text;
                //console.log("secret: " + vSecret);
                Storage.setSetting('CALLBACK', 'SECRET',vSecret);
             }
         }
      }


      Item
      {
         id : boxSendProvider
         anchors.top: inpSecret.bottom
         anchors.topMargin: 20
         anchors.margins: 10;
         height: 40;
         CheckBox
         {
            text : "Send coordinate provider";
            checked: (Storage.getSetting('CALLBACK','SEND_PROVIDER') === "Y") ? true : false;
            onClicked:
            {
               var vSendProvider = Storage.getSetting('CALLBACK','SEND_PROVIDER') === "Y" ? 'N' : 'Y';
               //console.log("Send provider:" + vSendProvider);
               Storage.setSetting('CALLBACK', 'SEND_PROVIDER',vSendProvider);
            }
         }
      }

      Item
      {
         id: boxSendAltitude
         anchors.top: boxSendProvider.bottom
         anchors.topMargin: 10;
         anchors.margins: 10;
         height: 40;
         CheckBox
         {
            text : "Send Altitude";
            checked: Storage.getSetting('CALLBACK','SEND_ALTITUDE') === "Y";
            onClicked:
            {
                var vSendAltitude = Storage.getSetting('CALLBACK','SEND_ALTITUDE') === "Y" ? 'N' : 'Y';
                //console.log("send altitude: " + vSendAltitude);
                Storage.setSetting('CALLBACK', 'SEND_ALTITUDE',vSendAltitude);
            }
         }
      }

      Item
      {
         id: boxSendTime
         anchors.top: boxSendAltitude.bottom
         anchors.topMargin: 10;
         anchors.margins: 10;
         height: 40;
         CheckBox
         {
            text : "Send time";
            checked: Storage.getSetting('CALLBACK','SEND_TIME') === "Y";
            onClicked:
            {
                var vSendTime = Storage.getSetting('CALLBACK','SEND_TIME') === "Y" ? 'N' : 'Y';
                //console.log("send time: " + vSendTime);
                Storage.setSetting('CALLBACK', 'SEND_TIME',vSendTime);
            }
         }
      }

      Item
      {
         id: boxSendBearing
         anchors.top: boxSendTime.bottom
         anchors.topMargin: 10;
         anchors.margins: 10;
         height: 40;
         CheckBox
         {
            text : "Send bearing";
            checked: Storage.getSetting('CALLBACK','SEND_BEARING') === "Y";
            onClicked:
            {
                var vSendBearing = Storage.getSetting('CALLBACK','SEND_BEARING') === "Y" ? 'N' : 'Y';
                //console.log("send bearing: " + vSendBearing);
                Storage.setSetting('CALLBACK', 'SEND_BEARING',vSendBearing);
            }
         }
      }

      Item
      {
         id: boxSendSpeed
         anchors.top: boxSendBearing.bottom
         anchors.topMargin: 10;
         anchors.margins: 10;
         height: 40;
         CheckBox
         {
            text : "Send Speed";
            checked: Storage.getSetting('CALLBACK','SEND_SPEED') === "Y";
            onClicked:
            {
                var vSendSpeed = Storage.getSetting('CALLBACK','SEND_SPEED') === "Y" ? 'N' : 'Y';
                //console.log("new Speed :" + vSendSpeed);
                Storage.setSetting('CALLBACK', 'SEND_SPEED',vSendSpeed);
            }
         }
      }

      Item
      {
         id : boxSendBattStatus
         anchors.top: boxSendSpeed.bottom
         anchors.topMargin: 10

         anchors.margins: 10;
         height: 40;
         CheckBox
         {
            text : "Send Battery Status";
            checked: (Storage.getSetting('CALLBACK','SEND_BATT_STATUS') === "Y") ? true : false;
            onClicked:
            {
               var vSendBattStatus = Storage.getSetting('CALLBACK','SEND_BATT_STATUS') === "Y" ? 'N' : 'Y';
               //console.log("New Batt status:" + vSendBattStatus);
               Storage.setSetting('CALLBACK', 'SEND_BATT_STATUS',vSendBattStatus);
            }
         }
      }

      Item
      {
         id : boxSendDeviceID
         anchors.top: boxSendBattStatus.bottom
         anchors.topMargin: 10

         anchors.margins: 10;
         height: 40;
         CheckBox
         {
            text : "Send device id";
            checked: (Storage.getSetting('CALLBACK','SEND_DEVID') === "Y") ? true : false;
            onClicked:
            {
               var vSendDeviceID = Storage.getSetting('CALLBACK','SEND_DEVID') === "Y" ? 'N' : 'Y';
               //console.log("Send device id: " + vSendDeviceID);
               Storage.setSetting('CALLBACK', 'SEND_DEVID',vSendDeviceID);
            }
         }
      }

      Item
      {
         id : boxSendSubscriberID
         anchors.top: boxSendDeviceID.bottom
         anchors.topMargin: 10

         anchors.margins: 10;
         height: 40;
         CheckBox
         {
            text : "Send subscriber id";
            checked: (Storage.getSetting('CALLBACK','SEND_SUBSCRID') === "Y") ? true : false;
            onClicked:
            {
               var vSendSubscriberID = Storage.getSetting('CALLBACK','SEND_SUBSCRID') === "Y" ? 'N' : 'Y';
               //console.log("Send subscriber id: " + vSendSubscriberID);
               Storage.setSetting('CALLBACK', 'SEND_SUBSCRID',vSendSubscriberID);
            }
         }
      }

      Item
      {
         id : boxResponseInNotifyBar
         anchors.top: boxSendSubscriberID.bottom
         anchors.topMargin: 10

         anchors.margins: 10;
         height: 40;
         CheckBox
         {
            text : "Http response in notify bar";
            checked: (Storage.getSetting('CALLBACK','HTTP_RESP_IN_NOTIF_BAR') === "Y") ? true : false;
            onClicked:
            {
               var vResponseInNotifyBar = Storage.getSetting('CALLBACK','HTTP_RESP_IN_NOTIF_BAR') === "Y" ? 'N' : 'Y';
               //console.log("Http response in notify bar: " + vResponseInNotifyBar);
               Storage.setSetting('CALLBACK', 'HTTP_RESP_IN_NOTIF_BAR',vResponseInNotifyBar);
            }
         }
      }

      }
   }

   ScrollDecorator
   {
      flickableItem: container
   }

   SelectionDialog
   {
      id: gpsFormatDialog
      titleText: "Coordinate Format"
      selectedIndex: Storage.getSetting('PROGRAMM','COORDINATE_FORMAT')
      model: ListModel
      {
         ListElement { name: "Degrees" }
         ListElement { name: "Degrees:minutes" }
         ListElement { name: "Degrees:minutes:seconds" }
      }
      onSelectedIndexChanged:
      {
         var vIndex = gpsFormatDialog.selectedIndex;
         //console.log("Index: " + vIndex);
         Storage.setSetting('PROGRAMM','COORDINATE_FORMAT',vIndex);
      }
   }
}
